[goffice] Compilation: grand renaming, part 4.



commit aeb443227c79e3c0b72bc817cc9920c45f2d0e87
Author: Morten Welinder <terra gnome org>
Date:   Wed Aug 19 21:03:04 2009 -0400

    Compilation: grand renaming, part 4.

 docs/reference/tmpl/gog-object.sgml   |   22 +++++++++++-----------
 goffice/app/file-priv.h               |    4 ++--
 goffice/app/file.c                    |   10 +++++-----
 goffice/app/file.h                    |    6 +++---
 goffice/app/go-plugin-loader-module.c |    4 ++--
 goffice/app/go-plugin-service.c       |    8 ++++----
 goffice/app/go-plugin-service.h       |    2 +-
 goffice/app/goffice-app.h             |   12 ++++++------
 goffice/app/io-context-priv.h         |    2 +-
 goffice/app/io-context.c              |   22 +++++++++++-----------
 goffice/app/io-context.h              |   18 +++++++++---------
 11 files changed, 55 insertions(+), 55 deletions(-)
---
diff --git a/docs/reference/tmpl/gog-object.sgml b/docs/reference/tmpl/gog-object.sgml
index dc3cd3e..69a0b86 100644
--- a/docs/reference/tmpl/gog-object.sgml
+++ b/docs/reference/tmpl/gog-object.sgml
@@ -54,53 +54,53 @@ Base class for all objects of graph model
 
 </para>
 
-@: 
-@: 
+ gogobject: the object which received the signal.
+ arg1: 
 
 <!-- ##### SIGNAL GogObject::child-added ##### -->
 <para>
 
 </para>
 
-@: 
-@: 
+ gogobject: the object which received the signal.
+ arg1: 
 
 <!-- ##### SIGNAL GogObject::child-name-changed ##### -->
 <para>
 
 </para>
 
-@: 
-@: 
+ gogobject: the object which received the signal.
+ arg1: 
 
 <!-- ##### SIGNAL GogObject::child-removed ##### -->
 <para>
 
 </para>
 
-@: 
-@: 
+ gogobject: the object which received the signal.
+ arg1: 
 
 <!-- ##### SIGNAL GogObject::children-reordered ##### -->
 <para>
 
 </para>
 
-@: 
+ gogobject: the object which received the signal.
 
 <!-- ##### SIGNAL GogObject::name-changed ##### -->
 <para>
 
 </para>
 
-@: 
+ gogobject: the object which received the signal.
 
 <!-- ##### SIGNAL GogObject::update-editor ##### -->
 <para>
 
 </para>
 
-@: 
+ gogobject: the object which received the signal.
 
 <!-- ##### ARG GogObject:alignment ##### -->
 <para>
diff --git a/goffice/app/file-priv.h b/goffice/app/file-priv.h
index 8453123..1b210d9 100644
--- a/goffice/app/file-priv.h
+++ b/goffice/app/file-priv.h
@@ -18,10 +18,10 @@ struct _GOFileOpenerClass {
 
 	/* private */
 	gboolean  (*can_probe) (GOFileOpener const *fo,
-				FileProbeLevel pl);
+				GOFileProbeLevel pl);
 	gboolean  (*probe) (GOFileOpener const *fo,
 	                    GsfInput *input,
-	                    FileProbeLevel pl);
+	                    GOFileProbeLevel pl);
 	void      (*open)  (GOFileOpener const *fo,
 			    gchar const *opt_enc,
 	                    GOIOContext *io_context,
diff --git a/goffice/app/file.c b/goffice/app/file.c
index e1c1767..1073aa2 100644
--- a/goffice/app/file.c
+++ b/goffice/app/file.c
@@ -54,14 +54,14 @@ go_file_opener_finalize (GObject *obj)
 }
 
 static gboolean
-go_file_opener_can_probe_real (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe_real (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	return fo->probe_func != NULL;
 }
 
 static gboolean
 go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
-			   FileProbeLevel pl)
+			   GOFileProbeLevel pl)
 {
 	gboolean ret = FALSE;
 
@@ -229,7 +229,7 @@ go_file_opener_is_encoding_dependent (GOFileOpener const *fo)
 }
 
 gboolean
-go_file_opener_can_probe (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 
@@ -254,14 +254,14 @@ go_file_opener_get_mimes (GOFileOpener const *fo)
  * go_file_opener_probe:
  * @fo      : #GOFileOpener
  * @input   : #GsfInput
- * @pl	    : #FileProbeLevel
+ * @pl	    : #GOFileProbeLevel
  *
  * Checks if a given file is supported by the opener.
  *
  * Returns: %TRUE, if the opener can read given file and %FALSE otherwise.
  **/
 gboolean
-go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel pl)
 {
 	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 	g_return_val_if_fail (GSF_IS_INPUT (input), FALSE);
diff --git a/goffice/app/file.h b/goffice/app/file.h
index 5bd8679..d0c92f6 100644
--- a/goffice/app/file.h
+++ b/goffice/app/file.h
@@ -50,7 +50,7 @@ typedef struct _GOFileOpenerClass GOFileOpenerClass;
 
 typedef gboolean (*GOFileOpenerProbeFunc) (GOFileOpener const *fo,
 					    GsfInput *input,
-					    FileProbeLevel pl);
+					    GOFileProbeLevel pl);
 typedef void     (*GOFileOpenerOpenFunc) (GOFileOpener const *fo,
 					  GOIOContext *io_context,
 					  gpointer FIXME_FIXME_workbook_view,
@@ -79,7 +79,7 @@ GOFileOpener *go_file_opener_new_with_enc (char const *id,
 
 
 gboolean     go_file_opener_probe (GOFileOpener const *fo, GsfInput *input,
-				    FileProbeLevel pl);
+				    GOFileProbeLevel pl);
 void         go_file_opener_open (GOFileOpener const *fo, gchar const *opt_enc,
 				  GOIOContext *io_context,
 				  gpointer FIXME_workbook_view,
@@ -89,7 +89,7 @@ char const *go_file_opener_get_id		  (GOFileOpener const *fo);
 char const *go_file_opener_get_description	  (GOFileOpener const *fo);
 gboolean    go_file_opener_is_encoding_dependent (GOFileOpener const *fo);
 gboolean    go_file_opener_can_probe		  (GOFileOpener const *fo,
-						   FileProbeLevel pl);
+						   GOFileProbeLevel pl);
 GSList const *go_file_opener_get_suffixes	  (GOFileOpener const *fo);
 GSList const *go_file_opener_get_mimes	  	  (GOFileOpener const *fo);
 
diff --git a/goffice/app/go-plugin-loader-module.c b/goffice/app/go-plugin-loader-module.c
index a61e460..366f5f6 100644
--- a/goffice/app/go-plugin-loader-module.c
+++ b/goffice/app/go-plugin-loader-module.c
@@ -205,7 +205,7 @@ GSF_CLASS_FULL (GOPluginLoaderModule, go_plugin_loader_module,
 
 typedef struct {
 	gboolean (*module_func_file_probe) (GOFileOpener const *fo, GsfInput *input,
-					    FileProbeLevel pl);
+					    GOFileProbeLevel pl);
 	void (*module_func_file_open) (GOFileOpener const *fo, GOIOContext *io_context,
 				       gpointer FIXME_FIXME_workbook_view,
 				       GsfInput *input);
@@ -213,7 +213,7 @@ typedef struct {
 
 static gboolean
 go_plugin_loader_module_func_file_probe (GOFileOpener const *fo, GOPluginService *service,
-					  GsfInput *input, FileProbeLevel pl)
+					  GsfInput *input, GOFileProbeLevel pl)
 {
 	ServiceLoaderDataFileOpener *loader_data;
 
diff --git a/goffice/app/go-plugin-service.c b/goffice/app/go-plugin-service.c
index 989d6ce..2489e11 100644
--- a/goffice/app/go-plugin-service.c
+++ b/goffice/app/go-plugin-service.c
@@ -397,25 +397,25 @@ go_plugin_file_opener_init (GOPluginFileOpener *fo)
 }
 
 static gboolean
-go_plugin_file_opener_can_probe (GOFileOpener const *fo, FileProbeLevel pl)
+go_plugin_file_opener_can_probe (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	GOPluginFileOpener *pfo = GO_PLUGIN_FILE_OPENER (fo);
 	GOPluginServiceFileOpener *service_file_opener = GO_PLUGIN_SERVICE_FILE_OPENER (pfo->service);
-	if (pl == FILE_PROBE_FILE_NAME)
+	if (pl == GO_FILE_PROBE_FILE_NAME)
 		return service_file_opener->suffixes != NULL;
 	return service_file_opener->has_probe;
 }
 
 static gboolean
 go_plugin_file_opener_probe (GOFileOpener const *fo, GsfInput *input,
-                               FileProbeLevel pl)
+                               GOFileProbeLevel pl)
 {
 	GOPluginFileOpener *pfo = GO_PLUGIN_FILE_OPENER (fo);
 	GOPluginServiceFileOpener *service_file_opener = GO_PLUGIN_SERVICE_FILE_OPENER (pfo->service);
 
 	g_return_val_if_fail (GSF_IS_INPUT (input), FALSE);
 
-	if (pl == FILE_PROBE_FILE_NAME && service_file_opener->suffixes != NULL) {
+	if (pl == GO_FILE_PROBE_FILE_NAME && service_file_opener->suffixes != NULL) {
 		GSList *ptr;
 		gchar const *extension;
 		gchar *lowercase_extension;
diff --git a/goffice/app/go-plugin-service.h b/goffice/app/go-plugin-service.h
index 3204be9..0403ffa 100644
--- a/goffice/app/go-plugin-service.h
+++ b/goffice/app/go-plugin-service.h
@@ -37,7 +37,7 @@ typedef struct {
 	/* plugin_func_file_probe may be NULL */
 	gboolean (*plugin_func_file_probe) (
 	         GOFileOpener const *fo, GOPluginService *service,
-	         GsfInput *input, FileProbeLevel pl);
+	         GsfInput *input, GOFileProbeLevel pl);
 	void     (*plugin_func_file_open) (
 	         GOFileOpener const *fo, GOPluginService *service,
 	         GOIOContext *io_context, gpointer fixme_workbook_view,
diff --git a/goffice/app/io-context-priv.h b/goffice/app/io-context-priv.h
index 67e78b7..a681485 100644
--- a/goffice/app/io-context-priv.h
+++ b/goffice/app/io-context-priv.h
@@ -43,7 +43,7 @@ typedef struct {
 	gfloat min, max;
 } ProgressRange;
 
-struct _IOContext {
+struct _GOIOContext {
 	GObject base;
 
 	GOCmdContext	*impl;
diff --git a/goffice/app/io-context.c b/goffice/app/io-context.c
index b609c96..41fdd76 100644
--- a/goffice/app/io-context.c
+++ b/goffice/app/io-context.c
@@ -248,7 +248,7 @@ go_io_warning_occurred (GOIOContext *context)
 }
 
 void
-io_progress_update (GOIOContext *ioc, gdouble f)
+go_io_progress_update (GOIOContext *ioc, gdouble f)
 {
 	gboolean at_end;
 
@@ -289,7 +289,7 @@ io_progress_update (GOIOContext *ioc, gdouble f)
 }
 
 void
-io_progress_message (GOIOContext *ioc, const gchar *msg)
+go_io_progress_message (GOIOContext *ioc, const gchar *msg)
 {
 	GOCmdContext *cc;
 
@@ -303,7 +303,7 @@ io_progress_message (GOIOContext *ioc, const gchar *msg)
 }
 
 void
-io_progress_range_push (GOIOContext *ioc, gdouble min, gdouble max)
+go_io_progress_range_push (GOIOContext *ioc, gdouble min, gdouble max)
 {
 	ProgressRange *r;
 	gdouble new_min, new_max;
@@ -324,7 +324,7 @@ io_progress_range_push (GOIOContext *ioc, gdouble min, gdouble max)
 }
 
 void
-io_progress_range_pop (GOIOContext *ioc)
+go_io_progress_range_pop (GOIOContext *ioc)
 {
 	GList *l;
 
@@ -352,7 +352,7 @@ io_progress_range_pop (GOIOContext *ioc)
 }
 
 void
-value_io_progress_set (GOIOContext *ioc, gint total, gint step)
+go_io_value_progress_set (GOIOContext *ioc, gint total, gint step)
 {
 	g_return_if_fail (GO_IS_IO_CONTEXT (ioc));
 	g_return_if_fail (total >= 0);
@@ -364,7 +364,7 @@ value_io_progress_set (GOIOContext *ioc, gint total, gint step)
 }
 
 void
-value_io_progress_update (GOIOContext *ioc, gint value)
+go_io_value_progress_update (GOIOContext *ioc, gint value)
 {
 	gdouble complete;
 	gint step, total;
@@ -382,11 +382,11 @@ value_io_progress_update (GOIOContext *ioc, gint value)
 	ioc->helper.v.value.last = value;
 
 	complete = (gdouble)value / total;
-	io_progress_update (ioc, complete);
+	go_io_progress_update (ioc, complete);
 }
 
 void
-count_io_progress_set (GOIOContext *ioc, gint total, gint step)
+go_io_count_progress_set (GOIOContext *ioc, gint total, gint step)
 {
 	g_return_if_fail (GO_IS_IO_CONTEXT (ioc));
 	g_return_if_fail (total >= 0);
@@ -399,7 +399,7 @@ count_io_progress_set (GOIOContext *ioc, gint total, gint step)
 }
 
 void
-count_io_progress_update (GOIOContext *ioc, gint inc)
+go_io_count_progress_update (GOIOContext *ioc, gint inc)
 {
 	gdouble complete;
 	gint current, step, total;
@@ -417,11 +417,11 @@ count_io_progress_update (GOIOContext *ioc, gint inc)
 	ioc->helper.v.count.last = current;
 
 	complete = (gdouble)current / total;
-	io_progress_update (ioc, complete);
+	go_io_progress_update (ioc, complete);
 }
 
 void
-io_progress_unset (GOIOContext *ioc)
+go_io_progress_unset (GOIOContext *ioc)
 {
 	g_return_if_fail (GO_IS_IO_CONTEXT (ioc));
 
diff --git a/goffice/app/io-context.h b/goffice/app/io-context.h
index b7faac9..b7ced20 100644
--- a/goffice/app/io-context.h
+++ b/goffice/app/io-context.h
@@ -27,18 +27,18 @@ void       go_io_error_display      (GOIOContext *ioc);
 gboolean   go_io_error_occurred     (GOIOContext *ioc);
 gboolean   go_io_warning_occurred   (GOIOContext *ioc);
 
-void       io_progress_message      (GOIOContext *io_context, const gchar *msg);
-void       io_progress_update       (GOIOContext *io_context, gdouble f);
-void       io_progress_range_push   (GOIOContext *io_context, gdouble min, gdouble max);
-void       io_progress_range_pop    (GOIOContext *io_context);
+void       go_io_progress_message      (GOIOContext *io_context, const gchar *msg);
+void       go_io_progress_update       (GOIOContext *io_context, gdouble f);
+void       go_io_progress_range_push   (GOIOContext *io_context, gdouble min, gdouble max);
+void       go_io_progress_range_pop    (GOIOContext *io_context);
 
-void       count_io_progress_set    (GOIOContext *io_context, gint total, gint step);
-void       count_io_progress_update (GOIOContext *io_context, gint inc);
+void       go_io_count_progress_set    (GOIOContext *io_context, gint total, gint step);
+void       go_io_count_progress_update (GOIOContext *io_context, gint inc);
 
-void       value_io_progress_set    (GOIOContext *io_context, gint total, gint step);
-void       value_io_progress_update (GOIOContext *io_context, gint value);
+void       go_io_value_progress_set    (GOIOContext *io_context, gint total, gint step);
+void       go_io_value_progress_update (GOIOContext *io_context, gint value);
 
-void       io_progress_unset      (GOIOContext *io_context);
+void       go_io_progress_unset      (GOIOContext *io_context);
 
 void go_io_context_set_num_files	(GOIOContext *ioc, guint count);
 void go_io_context_processing_file	(GOIOContext *ioc, char const *uri);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/goffice/app/goffice-app.h b/goffice/app/goffice-app.h
index 3448adf..aa56738 100644
--- a/goffice/app/goffice-app.h
+++ b/goffice/app/goffice-app.h
@@ -39,7 +39,7 @@ typedef struct _GOPluginLoader	GOPluginLoader;
 typedef struct _GOErrorInfo		GOErrorInfo;
 typedef struct _GOFileSaver 		GOFileSaver;
 typedef struct _GOFileOpener		GOFileOpener;
-typedef struct _IOContext		GOIOContext;
+typedef struct _GOIOContext		GOIOContext;
 
 /*
  * File probe level tells file opener (its probe method to be exact), how
@@ -48,14 +48,14 @@ typedef struct _IOContext		GOIOContext;
  * "reccomened" behaviour.
  * Before opening any file we detect its type by calling probe for
  * every registered file opener (in order of priority) and passing
  * FILE_PROBE_FILE_NAME as probe level. If none of them recogizes the file,
  * we increase probe level and try again...
  */
 typedef enum {
-	FILE_PROBE_FILE_NAME,	/* Test only file name, don't read file contents */
-	FILE_PROBE_CONTENT,	/* Read the whole file if it's necessary */
-	FILE_PROBE_LAST
-} FileProbeLevel;
+	GO_FILE_PROBE_FILE_NAME,	/* Test only file name, don't read file contents */
+	GO_FILE_PROBE_CONTENT,	/* Read the whole file if it's necessary */
+	GO_FILE_PROBE_LAST
+} GOFileProbeLevel;
 
 G_END_DECLS
 
@@ -48,14 +48,14 @@ typedef struct _IOContext		GOIOContext;
  * Before opening any file we detect its type by calling probe for
  * every registered file opener (in order of priority) and passing
- * FILE_PROBE_FILE_NAME as probe level. If none of them recogizes the file,
+ * GO_FILE_PROBE_FILE_NAME as probe level. If none of them recogizes the file,
  * we increase probe level and try again...
  */